@@ -34,9 +34,7 @@
 
 #include <KCalCore/Event>
 #include <KCalCore/MemoryCalendar>
-
-#include <KDGantt2/KDGanttGraphicsView>
-
+#include <KGantt/KGanttGraphicsView>
 #include <akonadi/calendar/freebusymanager.h>
 #include <kldap/ldapobject.h>
 
@@ -124,13 +122,12 @@ ResourceManagement::ResourceManagement(QWidget *parent)
 
     QWidget *w = new QWidget(this);
     mUi->setupUi(w);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(w);
 
     mainLayout->addWidget(buttonBox);
 
-    mModel = new KPIM::FreeBusyItemModel(this);
+    mModel = new CalendarSupport::FreeBusyItemModel(this);
     mFreebusyCalendar.setModel(mModel);
 
     mAgendaView = new EventViews::AgendaView(QDate(), QDate(), false,  false);
@@ -240,7 +237,7 @@ void ResourceManagement::showDetails(const KLDAP::LdapObject &obj, const KLDAP::
     QString name = QString::fromUtf8(obj.attributes().value(QStringLiteral("cn"))[0]);
     QString email = QString::fromUtf8(obj.attributes().value(QStringLiteral("mail"))[0]);
     KCalCore::Attendee::Ptr attendee(new KCalCore::Attendee(name,  email));
-    KPIM::FreeBusyItem::Ptr freebusy(new KPIM::FreeBusyItem(attendee, this));
+    CalendarSupport::FreeBusyItem::Ptr freebusy(new CalendarSupport::FreeBusyItem(attendee, this));
     mModel->clear();
     mModel->addItem(freebusy);
 }
